@@ -123,7 +123,7 @@ PipeOpMutate = R6Class("PipeOpMutate",
 # checks that `mutation` is
 # * a named list of `formula`
 # * that each element has only a lhs
-check_mutation_formulae = function(x) {
+check_mutation_formulae = crate(function(x) {
   check_list(x, types = "formula", names = "unique") %check&&%
     Reduce(`%check&&%`, lapply(x, function(xel) {
       if (length(xel) != 2) {
@@ -132,6 +132,6 @@ check_mutation_formulae = function(x) {
       }
       TRUE
     }), TRUE)
-}
+}, .parent = topenv())
 
 mlr_pipeops$add("mutate", PipeOpMutate)
