@@ -79,32 +79,37 @@ PipeOpSmote = R6Class("PipeOpSmote",
         # so it is a 'special_vals'.
         dup_size = p_int(lower = 1, default = 0, special_vals = list(0), tags = c("train", "smote"))
       )
-      super$initialize(id, param_set = ps, param_vals = param_vals,
-        packages = "smotefamily", can_subset_cols = FALSE, tags = "imbalanced data")
+      super$initialize(id, param_set = ps, param_vals = param_vals, can_subset_cols = FALSE,
+        packages = "smotefamily", task_type = "TaskClassif", tags = "imbalanced data")
     }
   ),
   private = list(
 
     .train_task = function(task) {
-      assert_true(all(task$feature_types$type == "numeric"))
-      cols = private$.select_cols(task)
-
+      cols = task$feature_names
+      unsupported_cols = setdiff(unlist(task$col_roles), union(cols, task$target_names))
+      if (length(unsupported_cols)) {
+        stopf("SMOTE cannot generate synthetic data for the following columns since they are neither features nor targets: %s.",
+              str_collapse(unsupported_cols, quote = '"'))
+      }
       if (!length(cols)) {
-        self$state = list(dt_columns = cols)
         return(task)
       }
-      dt = task$data(cols = cols)
+      if (!all(task$feature_types$type %in% c("numeric"))) {
+        stop("Smote does only accept numeric features. Use PipeOpSelect to select the appropriate features.")
+      }
 
-      # calculate synthetic data
+      # Calculate synthetic data
+      dt = task$data(cols = cols)
       st = setDT(invoke(smotefamily::SMOTE, X = dt, target = task$truth(),
         .args = self$param_set$get_values(tags = "smote"),
         .opts = list(warnPartialMatchArgs = FALSE))$syn_data)
 
-      # rename target column and fix character conversion for TaskClassif
-      if (task$task_type == "classif") {
-        st[["class"]] = as_factor(st[["class"]], levels = task$class_names)
-      }
-      setnames(st, "class", task$target_names)
+      # Rename target column and fix character conversion
+      # We index by position (target should be last column) instead of indexing by name, which would lead to problems if a feature were called "class"
+      st[[ncol(st)]] = as_factor(st[[ncol(st)]], levels = task$class_names)
+      setnames(st, ncol(st), task$target_names)
+
       task$rbind(st)
     }
   )
