@@ -115,3 +115,21 @@ multiplicity_nests_deeper_than = function(x, cutoff) {
   }
   ret
 }
+
+#' @export
+marshal_model.Multiplicity = function(model, inplace = FALSE, ...) {
+  maybe_marshaled = multiplicity_recurse(model, marshal_model, inplace = inplace, ...)
+  was_marshaled = unlist(multiplicity_recurse(maybe_marshaled, is_marshaled_model))
+  if (!any(was_marshaled)) {
+    return(model)
+  }
+  structure(list(
+    marshaled = maybe_marshaled,
+    packages = "mlr3pipelines"
+  ), class = c("Multiplicity_marshaled", "marshaled"))
+}
+
+#' @export
+unmarshal_model.Multiplicity_marshaled = function(model, inplace = FALSE, ...) {
+  multiplicity_recurse(model$marshaled, unmarshal_model, inplace = inplace, ...)
+}
