@@ -104,6 +104,15 @@ multiplicity_recurse = function(.multip, .fun, ...) {
   }
 }
 
+multiplicity_flatten = function(.multip) {
+  # returns list(.multip) if .multip is not a Multiplicity
+  # Otherwise, it returns a list with all the elements contained in .multip, independent of their nesting level
+  if (!is.Multiplicity(.multip)) {
+    return(list(.multip))
+  }
+  unlist(map(.multip, multiplicity_flatten), recursive = FALSE, use.names = FALSE)
+}
+
 # replace when new mlr3misc version is released https://github.com/mlr-org/mlr3misc/pull/80
 dictionary_sugar_inc_get = function(dict, .key, ...) {
   newkey = gsub("_\\d+$", "", .key)
@@ -134,3 +143,22 @@ dictionary_sugar_inc_mget = function(dict, .keys, ...) {
   names(objs) = map_chr(objs, "id")
   objs
 }
+
+pos_with_property = function(x, property) {
+  x = if (test_class(x, "GraphLearner")) {
+    x$graph$pipeops
+  } else if(test_class(x, "Graph")) {
+    x$pipeops
+  } else {
+    x
+  }
+  keep(x, function(po) property %in% po$properties)
+}
+
+assert_po_validate = function(rhs) {
+  assert_choice(rhs, "predefined", null.ok = TRUE)
+}
+
+test_po_validate = function(x) {
+  test_choice(x, "predefined", null.ok = TRUE)
+}
