@@ -27,7 +27,7 @@ test_that("PipeOpLearnerCV - basic properties", {
   expect_character(setdiff(vals, task$class_names), len = 0)
 
   lrn = mlr_learners$get("classif.featureless")
-  iris_with_unambiguous_mode = mlr_tasks$get("iris")$filter(c(1:49, 52:150))  # want featureless learner without randomness
+  iris_with_unambiguous_mode = mlr_tasks$get("iris")$filter(c(1:30, 70:150))  # want featureless learner without randomness
   expect_datapreproc_pipeop_class(PipeOpLearnerCV,
     list(lrn), iris_with_unambiguous_mode, predict_like_train = FALSE, deterministic_train = FALSE, check_ps_default_values = FALSE)
   # 'insample' PipeOpLearnerCV with deterministic Learner is deterministic in every regard!
@@ -54,13 +54,14 @@ test_that("PipeOpLearnerCV - within resampling", {
   skip_if_not_installed("rpart")
   lrn = mlr_learners$get("classif.rpart")
   gr = GraphLearner$new(PipeOpLearnerCV$new(lrn) %>>% po(id = "l2", lrn))
-  resample(tsk("iris"), gr, rsmp("holdout"))
+  rr = resample(tsk("iris"), gr, rsmp("holdout"))
+  expect_class(rr, "ResampleResult")
 })
 
 test_that("PipeOpLearnerCV - insample resampling", {
   skip_if_not_installed("rpart")
   lrn = mlr_learners$get("classif.featureless")
-  iris_with_unambiguous_mode = mlr_tasks$get("iris")$filter(c(1:49, 52:150))  # want featureless learner without randomness
+  iris_with_unambiguous_mode = mlr_tasks$get("iris")$filter(c(1:30, 70:150))  # want featureless learner without randomness
 
   polrn = PipeOpLearnerCV$new(lrn, param_vals = list(resampling.method = "insample"))
   expect_equal(polrn$train(list(iris_with_unambiguous_mode))[[1]]$data(),
@@ -125,3 +126,81 @@ test_that("predict_type", {
     lcv$train(list(tsk("iris")))[[1]]$feature_names)
 
 })
+
+test_that("marshal", {
+  task = tsk("iris")
+  po_lrn = as_pipeop(po("learner_cv", learner = lrn("classif.debug")))
+  po_lrn$train(list(task))
+  po_state = po_lrn$state
+  expect_class(po_state, "pipeop_learner_cv_state")
+  po_state_marshaled = marshal_model(po_state, inplace = FALSE)
+  expect_class(po_state_marshaled, "pipeop_learner_cv_state_marshaled")
+  expect_true(is_marshaled_model(po_state_marshaled))
+  expect_equal(po_state, unmarshal_model(po_state_marshaled))
+})
+
+test_that("marshal multiplicity", {
+  po = po("learner_cv", learner = lrn("classif.debug"))
+  po$train(list(Multiplicity(tsk("iris"), tsk("sonar"))))
+  s = po$state
+  sm = marshal_model(po$state)
+  expect_class(po$state, "Multiplicity")
+  expect_true(is_marshaled_model(sm$marshaled[[1L]]))
+  expect_true(is_marshaled_model(sm$marshaled[[2L]]))
+
+  su = unmarshal_model(sm)
+  expect_equal(su, s)
+
+  # recursive
+  po = po("learner_cv", learner = lrn("classif.debug"))
+  po$train(list(Multiplicity(Multiplicity(tsk("iris")))))
+  p1 = po$predict(list(Multiplicity(Multiplicity(tsk("iris")))))
+
+  s = po$state
+  sm = marshal_model(po$state)
+  expect_class(po$state, "Multiplicity")
+  expect_true(is_marshaled_model(sm$marshaled[[1L]][[1L]]))
+
+  su = unmarshal_model(sm)
+  expect_equal(su, s)
+
+  po$state = su
+  p2 = po$predict(list(Multiplicity(Multiplicity(tsk("iris")))))
+  expect_equal(p1, p2)
+
+
+  task = tsk("iris")
+  learner = lrn("classif.debug")
+
+  lrncv_po = po("learner_cv", learner)
+  lrncv_po$learner$predict_type = "response"
+
+  nop = mlr_pipeops$get("nop")
+
+  graph = gunion(list(
+    lrncv_po,
+    nop
+  )) %>>% po("featureunion") %>>% lrn("classif.rpart")
+
+  glrn = as_learner(graph)
+  expect_learner(glrn, task)
+
+  p1 = glrn$train(task)$predict(task)
+  p2 = glrn$marshal()$unmarshal()$predict(task)
+  expect_equal(p1, p2)
+
+})
+
+test_that("state class and multiplicity", {
+  po = po("learner_cv", learner = lrn("classif.debug"))
+  po$train(list(Multiplicity(tsk("iris"))))
+  expect_class(po$state, "Multiplicity")
+  expect_class(po$state[[1L]], "pipeop_learner_cv_state")
+
+  # recursive
+  po1 = po("learner_cv", learner = lrn("classif.debug"))
+  po1$train(list(Multiplicity(Multiplicity(tsk("iris")))))
+  expect_class(po1$state, "Multiplicity")
+  expect_class(po1$state[[1L]], "Multiplicity")
+  expect_class(po1$state[[1L]][[1L]], "pipeop_learner_cv_state")
+})
